Architecture
============

.. COMMENT

.. toctree::
   :maxdepth: 2



.. comment, because graqphwiz currently doesn't work on my mac
  x

Class Inheritance Diagram
-------------------------

.. inheritance-diagram:: fabulist.fabulist
   :parts: 1
   :private-bases:

.. inheritance-diagram:: fabulist.lorem_ipsum
   :parts: 1
   :private-bases:
